@@ -184,7 +184,7 @@ shorten_disk_name (const char *dev, gint len)
 {
     char *r, *lastchars, *firstchars;
     //if (strncmp(dev, "UUID", 4)==0 && 
-    if (strlen(dev)>len+3)
+    if (strlen(dev)>len) // len canot be set lower than 9
     {
         // we want at least 5 characters at the end so that trimmed UUIDs are still readable
         lastchars = (char *) (dev + strlen(dev) - 5);
@@ -325,8 +325,12 @@ disk_umount (t_disk *pdisk, char* umount_command, gboolean show_message_dialog,
     if (pdisk != NULL)
     {
 
-        DBG("disk_umount: dev=%s, mountpoint=%s, umount_command=%s, show_message_dialog=%d, eject=%d", pdisk->device, pdisk->mount_point, umount_command, show_message_dialog, eject);
-        deviceprintf(&tmp, umount_command, pdisk->device);
+        DBG("disk_umount: dev=%s, mountpoint=%s, umount_command=%s, show_message_dialog=%d, eject=%d, type=%s", pdisk->device, pdisk->mount_point, umount_command, show_message_dialog, eject, pdisk->mount_info->type);
+        if (strstr(pdisk->mount_info->type, "fuse"))
+          deviceprintf(&tmp, "fusermount -u %m", pdisk->device);
+        else
+          deviceprintf(&tmp, umount_command, pdisk->device);
+        
         mountpointprintf(&cmd, tmp, pdisk->mount_point);
         /* cmd contains umount_command device mount_point */
         val = g_spawn_command_line_sync (cmd, &output, &erroutput, &exit_status, &error);
@@ -655,18 +659,20 @@ disks_refresh(GPtrArray * pdisks, GPtrArray *excluded_FSs, gint length)
               g_ascii_strcasecmp(pmntent->mnt_dir, "none") == 0 ||
               g_str_has_prefix(pmntent->mnt_fsname, "gvfs-fuse-daemon") ||
               !(g_str_has_prefix(pmntent->mnt_fsname, "/dev/") ||
-              g_str_has_prefix(pmntent->mnt_type, "fuse") ||
-              g_str_has_prefix(pmntent->mnt_type, "nfs") ||
-              g_str_has_prefix(pmntent->mnt_type, "smbfs") ||
-              g_str_has_prefix(pmntent->mnt_type, "cifs") ||
-              g_str_has_prefix(pmntent->mnt_type, "shfs") ) ||
+                g_str_has_prefix(pmntent->mnt_type, "fuse") ||
+                g_str_has_prefix(pmntent->mnt_type, "nfs") ||
+                g_str_has_prefix(pmntent->mnt_type, "smbfs") ||
+                g_str_has_prefix(pmntent->mnt_type, "cifs") ||
+                g_str_has_prefix(pmntent->mnt_type, "shfs") 
+              ) ||
               g_str_has_prefix(pmntent->mnt_dir, "/sys/")
 #elif defined (HAVE_GETMNTINFO)
               /* TODO: add support for more fs types on BSD */
               g_ascii_strcasecmp(pstatfs[i].f_mntonname, "none") == 0 ||
-              !g_str_has_prefix(pstatfs[i].f_mntfromname, "/dev/") ||
-              g_str_has_prefix(pstatfs[i].f_fstypename, "nfs") ||
-              g_str_has_prefix(pstatfs[i].f_fstypename, "mfs")
+              !(g_str_has_prefix(pstatfs[i].f_mntfromname, "/dev/") ||
+                g_str_has_prefix(pstatfs[i].f_fstypename, "nfs") ||
+                g_str_has_prefix(pstatfs[i].f_fstypename, "mfs")
+              )
 #endif
             ) continue;
 
@@ -717,9 +723,9 @@ disk_classify (char *device, char *mountpoint)
             dc = REMOTE;
         }
     }
-    else if ( strstr(device, "cdrom") || strstr(device, "cdrw") || strstr(device, "cd")
-                || strstr(device, "dvd") || strstr(mountpoint, "cdrom")
-                || strstr(mountpoint, "cdrw") || strstr(mountpoint, "dvd")) {
+		/* it needs to be said _here_ that BSDs use cd0, cd1 etc., so we hope cd* works for cdrw, cdrom and cd0,1,... nd no other devices */
+    else if ( strstr(device, "cd") 
+                || strstr(device, "dvd") || strstr(mountpoint, "cd") || strstr(mountpoint, "dvd")) {
         dc = CD_DVD;
     }
     else if ( strstr(mountpoint, "usr") || strstr(mountpoint, "var")
